@@ -35,6 +35,11 @@ async def list_roles(
     )
 
 
+@router.get("/{id:uuid}", name="roles:get", response_model=schemas.role.Role)
+async def get_role(role: Role = Depends(get_role_by_id_or_404)) -> Role:
+    return role
+
+
 @router.post(
     "/",
     name="roles:create",
@@ -113,8 +118,8 @@ async def update_role(
     send_task(
         on_role_updated,
         str(role.id),
-        list(map(str, added_permissions)),
-        list(map(str, deleted_permissions)),
+        set(map(str, added_permissions)),
+        set(map(str, deleted_permissions)),
         str(workspace.id),
     )
 
