@@ -65,9 +65,11 @@ from fief.repositories import (
     RoleRepository,
     TenantRepository,
     UserPermissionRepository,
+    UserRepository,
     UserRoleRepository,
 )
 from fief.services.webhooks.models import (
+    UserDeleted,
     UserPermissionCreated,
     UserPermissionDeleted,
     UserRoleCreated,
@@ -346,6 +348,35 @@ async def create_user_access_token(
     return await form_helper.get_response()
 
 
+@router.api_route(
+    "/{id:uuid}/delete",
+    methods=["GET", "DELETE"],
+    name="dashboard.users:delete",
+)
+async def delete_user(
+    request: Request,
+    user: User = Depends(get_user_by_id_or_404),
+    repository: UserRepository = Depends(get_workspace_repository(UserRepository)),
+    list_context=Depends(get_list_context),
+    context: BaseContext = Depends(get_base_context),
+    audit_logger: AuditLogger = Depends(get_audit_logger),
+    trigger_webhooks: TriggerWebhooks = Depends(get_trigger_webhooks),
+):
+    if request.method == "DELETE":
+        await repository.delete(user)
+        audit_logger.log_object_write(AuditLogMessage.OBJECT_DELETED, user)
+        trigger_webhooks(UserDeleted, user, schemas.user.UserRead)
+
+        return HXRedirectResponse(
+            request.url_for("dashboard.users:list"),
+            status_code=status.HTTP_204_NO_CONTENT,
+        )
+    else:
+        return templates.TemplateResponse(
+            "admin/users/delete.html", {**context, **list_context, "user": user}
+        )
+
+
 @router.api_route(
     "/{id:uuid}/permissions",
     methods=["GET", "POST"],
@@ -404,7 +435,7 @@ async def user_permissions(
                 "already_added_permission",
             )
 
-        user_permission = UserPermission(user_id=user.id, permission_id=permission_id)
+        user_permission = UserPermission(user_id=user.id, permission=permission)
         await user_permission_repository.create(user_permission)
         audit_logger.log_object_write(
             AuditLogMessage.OBJECT_CREATED,
@@ -515,7 +546,7 @@ async def user_roles(
                 "This role is already granted to this user.", "already_added_role"
             )
 
-        user_role = UserRole(user_id=user.id, role_id=role_id)
+        user_role = UserRole(user_id=user.id, role=role)
         await user_role_repository.create(user_role)
         audit_logger.log_object_write(
             AuditLogMessage.OBJECT_CREATED,
