@@ -5,9 +5,9 @@ from sqlalchemy import select
 from fief.dependencies.pagination import (
     GetPaginatedObjects,
     Ordering,
+    OrderingGetter,
     PaginatedObjects,
     Pagination,
-    get_ordering,
     get_paginated_objects_getter,
     get_pagination,
 )
@@ -18,7 +18,7 @@ from fief.repositories import EmailTemplateRepository
 
 async def get_paginated_email_templates(
     pagination: Pagination = Depends(get_pagination),
-    ordering: Ordering = Depends(get_ordering),
+    ordering: Ordering = Depends(OrderingGetter()),
     repository: EmailTemplateRepository = Depends(
         get_workspace_repository(EmailTemplateRepository)
     ),
