@@ -5,9 +5,9 @@ from sqlalchemy import or_, select
 from fief.dependencies.pagination import (
     GetPaginatedObjects,
     Ordering,
+    OrderingGetter,
     PaginatedObjects,
     Pagination,
-    get_ordering,
     get_paginated_objects_getter,
     get_pagination,
 )
@@ -20,7 +20,7 @@ from fief.repositories import OAuthProviderRepository
 async def get_paginated_oauth_providers(
     query: str | None = Query(None),
     pagination: Pagination = Depends(get_pagination),
-    ordering: Ordering = Depends(get_ordering),
+    ordering: Ordering = Depends(OrderingGetter()),
     repository: OAuthProviderRepository = Depends(
         get_workspace_repository(OAuthProviderRepository)
     ),
