@@ -7,9 +7,9 @@ from fief import schemas
 from fief.dependencies.pagination import (
     GetPaginatedObjects,
     Ordering,
+    OrderingGetter,
     PaginatedObjects,
     Pagination,
-    get_ordering,
     get_paginated_objects_getter,
     get_pagination,
 )
@@ -52,7 +52,7 @@ async def get_tenant_from_create_user_internal(
 async def get_paginated_tenants(
     query: str | None = Query(None),
     pagination: Pagination = Depends(get_pagination),
-    ordering: Ordering = Depends(get_ordering),
+    ordering: Ordering = Depends(OrderingGetter()),
     repository: TenantRepository = Depends(get_workspace_repository(TenantRepository)),
     get_paginated_objects: GetPaginatedObjects[Tenant] = Depends(
         get_paginated_objects_getter
