@@ -23,6 +23,7 @@ from wtforms import (
     StringField,
     TelField,
     validators,
+    widgets,
 )
 from wtforms.csrf.core import CSRF
 from wtforms.utils import unset_value
@@ -229,6 +230,11 @@ class ComboboxSelectMultipleField(SelectMultipleField):
             self.data = None
 
 
+class SelectMultipleFieldCheckbox(SelectMultipleField):
+    widget = widgets.ListWidget()
+    option_widget = widgets.CheckboxInput()
+
+
 class TimezoneField(SelectField):
     def __init__(self, *args, **kwargs):
         choices = [""] + sorted(pytz.common_timezones)
