@@ -1,5 +1,6 @@
 from pydantic import UUID4
-from sqlalchemy import Column, ForeignKey, String
+from sqlalchemy import ForeignKey, String
+from sqlalchemy.orm import Mapped, mapped_column
 
 from fief.models.base import MainBase
 from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
@@ -9,9 +10,9 @@ from fief.models.workspace import Workspace
 class AdminAPIKey(UUIDModel, CreatedUpdatedAt, MainBase):
     __tablename__ = "admin_api_key"
 
-    name: str = Column(String(length=255), nullable=False)
-    token: str = Column(String(length=255), unique=True, nullable=False)
-    workspace_id: UUID4 = Column(
+    name: Mapped[str] = mapped_column(String(length=255), nullable=False)
+    token: Mapped[str] = mapped_column(String(length=255), unique=True, nullable=False)
+    workspace_id: Mapped[UUID4] = mapped_column(
         GUID, ForeignKey(Workspace.id, ondelete="CASCADE"), nullable=False
     )
 
