@@ -4,7 +4,8 @@ import uuid
 
 from fief_client import FiefTokenResponse, FiefUserInfo
 from pydantic import UUID4
-from sqlalchemy import Column, String, Text
+from sqlalchemy import String, Text
+from sqlalchemy.orm import Mapped, mapped_column
 
 from fief.models.base import MainBase
 from fief.models.generics import CreatedUpdatedAt, UUIDModel
@@ -13,9 +14,9 @@ from fief.models.generics import CreatedUpdatedAt, UUIDModel
 class AdminSessionToken(UUIDModel, CreatedUpdatedAt, MainBase):
     __tablename__ = "admin_session_tokens"
 
-    token: str = Column(String(length=255), unique=True, nullable=False)
-    raw_tokens: str = Column(Text, nullable=False)
-    raw_userinfo: str = Column(Text, nullable=False)
+    token: Mapped[str] = mapped_column(String(length=255), unique=True, nullable=False)
+    raw_tokens: Mapped[str] = mapped_column(Text, nullable=False)
+    raw_userinfo: Mapped[str] = mapped_column(Text, nullable=False)
 
     def __repr__(self) -> str:
         return f"AdminSessionToken(id={self.id})"
